@@ -1,7 +1,7 @@
 package App::ParseSearchStringFromURL;
 
-our $DATE = '2017-11-06'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-05-26'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -92,7 +92,7 @@ App::ParseSearchStringFromURL - Parse search string from URL
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ParseSearchStringFromURL (from Perl distribution App-ParseSearchStringFromURL), released on 2017-11-06.
+This document describes version 0.003 of App::ParseSearchStringFromURL (from Perl distribution App-ParseSearchStringFromURL), released on 2021-05-26.
 
 =head1 FUNCTIONS
 
@@ -101,7 +101,7 @@ This document describes version 0.002 of App::ParseSearchStringFromURL (from Per
 
 Usage:
 
- parse_search_string_from_url(%args) -> [status, msg, result, meta]
+ parse_search_string_from_url(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Parse search string from URL.
 
@@ -119,16 +119,17 @@ If set to true, will also output other components aside from search string.
 
 =item * B<urls>* => I<array[url]>
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -142,7 +143,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-ParseSearchStrin
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ParseSearchStringFromURL>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-ParseSearchStringFromURL/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -154,7 +155,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
